@@ -59,7 +59,7 @@ class VardbPackage():
                     buf = f.read(10000)
                 else:
                     buf += f.read(10000)
-                if "isz=" in buf:
+                if b"isz=" in buf:
                     self.set_detected(True)
                     return True
         self.set_detected(False)
